@@ -30,6 +30,9 @@
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+#include <sys/ioctl.h>
 
 #ifdef HAVE_LINUX_FD_H
 #include <linux/fd.h>
