@@ -27,8 +27,8 @@
 #include <sys/stat.h>
 #include "logview.h"
 
-#define LOG_CANVAS_H             400
-#define LOG_CANVAS_W             600
+#define LOGVIEW_DEFAULT_HEIGHT 400
+#define LOGVIEW_DEFAULT_WIDTH 600
 
 #define GCONF_WIDTH_KEY  "/apps/gnome-system-log/width"
 #define GCONF_HEIGHT_KEY "/apps/gnome-system-log/height"
@@ -81,12 +81,15 @@ prefs_create_defaults (UserPrefs *p)
 {
 	int i;
 	gchar *logfiles[] = {"/var/adm/messages",
-                       "/var/log/messages",
-                       "/var/log/sys.log",
-                       "/var/log/secure",
-                       "/var/log/maillog",
-                       "/var/log/cron",
-                       "/var/log/XFree86.0.log"};
+                         "/var/log/messages",
+                         "/var/log/sys.log",
+                         "/var/log/secure",
+                         "/var/log/maillog",
+                         "/var/log/cron",
+                         "/var/log/Xorg.0.log",
+                         "/var/log/XFree86.0.log",
+                         "/var/log/auth.log",
+                         "/var/log/cups/error_log"};
 	struct stat filestat;
 	GSList *logs = NULL;
 	GnomeVFSResult result;
@@ -103,7 +106,7 @@ prefs_create_defaults (UserPrefs *p)
 		logs = parse_syslog ("/etc/syslog.conf");
 	}
 	
-	for (i=0; i<7; i++) {
+	for (i=0; i<10; i++) {
 		if (file_is_log (logfiles[i], FALSE))
 			logs = g_slist_append (logs, g_strdup(logfiles[i]));
 	}
@@ -122,33 +125,34 @@ prefs_load (GConfClient *client)
 	UserPrefs *p;
 	GSList *list;
 	gboolean found;
+    GError *err;
 
     g_assert (client != NULL);
 
 	p = g_new0 (UserPrefs, 1);
 
-	p->logs = gconf_client_get_list (client, GCONF_LOGFILES, GCONF_VALUE_STRING, NULL);
-	if (p->logs == NULL)
+	p->logs = gconf_client_get_list (client, GCONF_LOGFILES, GCONF_VALUE_STRING, &err);
+	if (err != NULL)
 		prefs_create_defaults (p);
 
 	logfile = gconf_client_get_string (client, GCONF_LOGFILE, NULL);
 	if (logfile != NULL && strcmp (logfile, "") && file_is_log(logfile, FALSE)) {
 		p->logfile = g_strdup (logfile);
 		g_free (logfile);
-	}
-
-	found = FALSE;
-	for (list = p->logs; list!=NULL; list = g_slist_next (list)) {
-		if (g_ascii_strncasecmp (list->data, p->logfile, 255) == 0)
-			found = TRUE;
+	
+		found = FALSE;
+		for (list = p->logs; list!=NULL; list = g_slist_next (list)) {
+		  if (g_ascii_strncasecmp (list->data, p->logfile, 255) == 0)
+		    found = TRUE;
+		}
 	}
 
 	width = gconf_client_get_int (client, GCONF_WIDTH_KEY, NULL);
 	height = gconf_client_get_int (client, GCONF_HEIGHT_KEY, NULL);
 	fontsize = gconf_client_get_int (client, GCONF_FONTSIZE_KEY, NULL);
 
-	p->width = (width == 0 ? LOG_CANVAS_W : width);
-	p->height = (height == 0 ? LOG_CANVAS_H : height);
+	p->width = (width == 0 ? LOGVIEW_DEFAULT_WIDTH : width);
+	p->height = (height == 0 ? LOGVIEW_DEFAULT_HEIGHT : height);
 	p->fontsize = fontsize;
 
 	return p;
@@ -158,7 +162,7 @@ static void
 prefs_monospace_font_changed (GConfClient *client, guint id, 
                                 GConfEntry *entry, gpointer data)
 {
-    GtkWidget *view = data;
+  GtkWidget *view = GTK_WIDGET (data);
     gchar *monospace_font_name;
     PangoFontDescription *fontdesc;
 
@@ -169,6 +173,17 @@ prefs_monospace_font_changed (GConfClient *client, guint id,
     g_free (monospace_font_name);
 }
 
+static void
+prefs_menus_have_tearoff_changed (GConfClient *client, guint id,
+								  GConfEntry *entry, gpointer data)
+{
+  LogviewWindow *logview = LOGVIEW_WINDOW (data);
+    
+  g_assert (client != NULL);      
+  gtk_ui_manager_set_add_tearoffs (logview->ui_manager, 
+								   prefs_get_have_tearoff ());
+}
+
 gchar *
 prefs_get_monospace (void)
 {
@@ -238,19 +253,19 @@ prefs_save (void)
 {
   GSList *logs;
 
-	if (gconf_client_key_is_writable (client, GCONF_LOGFILE, NULL) &&
-	    prefs->logfile != NULL) {
-		gconf_client_set_string (client, GCONF_LOGFILE, prefs->logfile, NULL);
-	}
+    if (prefs->logfile)
+        if (gconf_client_key_is_writable (client, GCONF_LOGFILE, NULL))
+	    gconf_client_set_string (client, GCONF_LOGFILE, prefs->logfile, NULL);
+
+    if (gconf_client_key_is_writable (client, GCONF_LOGFILES, NULL))
+        gconf_client_set_list (client, GCONF_LOGFILES, GCONF_VALUE_STRING, prefs->logs, NULL);
+
 	if (prefs->width > 0 && prefs->height > 0) {
 		if (gconf_client_key_is_writable (client, GCONF_WIDTH_KEY, NULL))
 			gconf_client_set_int (client, GCONF_WIDTH_KEY, prefs->width, NULL);
 		if (gconf_client_key_is_writable (client, GCONF_HEIGHT_KEY, NULL))
 			gconf_client_set_int (client, GCONF_HEIGHT_KEY, prefs->height, NULL);
 	}
-	if (prefs->logs != NULL)
-		if (gconf_client_key_is_writable (client, GCONF_LOGFILES, NULL))
-			gconf_client_set_list (client, GCONF_LOGFILES, GCONF_VALUE_STRING, prefs->logs, NULL);
 
 	if (prefs->fontsize > 0)
 		if (gconf_client_key_is_writable (client, GCONF_FONTSIZE_KEY, NULL))
@@ -263,9 +278,8 @@ prefs_store_window_size (GtkWidget *window)
 	int width, height;
 
     g_return_if_fail (GTK_IS_WINDOW (window));
-
+      
 	gtk_window_get_size (GTK_WINDOW(window), &width, &height);
-	/* FIXME : we should check the state of the window, maximized or not */
 	if (width > 0 && height > 0) {
 		prefs->width = width;
 		prefs->height = height;
@@ -278,7 +292,11 @@ prefs_connect (LogviewWindow *logview)
     g_return_if_fail (LOGVIEW_IS_WINDOW (logview));
 
     gconf_client_notify_add (client, GCONF_MONOSPACE_FONT_NAME, 
-                             prefs_monospace_font_changed, logview->view, NULL, NULL);
+                             (GConfClientNotifyFunc) prefs_monospace_font_changed,
+							 logview->view, NULL, NULL);
+    gconf_client_notify_add (client, GCONF_MENUS_HAVE_TEAROFF,
+							 (GConfClientNotifyFunc) prefs_menus_have_tearoff_changed,
+							 logview, NULL, NULL);
 }
 
 void
